# main entry point for CLI applications.

import logging
import argparse
from groovylight.config import Config

logger = logging.getLogger(__loader__.name)


def setup_logger(args):
    root_logger = logging.getLogger()
    handler = logging.StreamHandler()

    formatter = logging.Formatter(
        style=r"{", fmt=r"{levelname:s}: {name:s}: {message:s}"
    )

    handler.setFormatter(formatter)

    root_logger.addHandler(handler)
    root_logger.setLevel(args.loglevel)


def main():
    parser = argparse.ArgumentParser()

    parser.add_argument(
        "-d",
        "--debug",
        help="Print debug-level statements",
        action="store_const",
        dest="loglevel",
        const=logging.DEBUG,
        default=logging.INFO,
    )

    parser.add_argument(
        "-L",
        "--log-file",
        help="Log to file",
        type=argparse.FileType("w"),
        metavar="FILE",
    )

    parser.add_argument(
        "config",
        help="Configuration file",
        type=argparse.FileType("rb"),
        metavar="FILE",
    )

    args = parser.parse_args()

    setup_logger(args)

    conf = Config(args.config)
    print(conf)



if __name__ == "__main__":
    main()
