from ..geom import Coord, BBox, DisplayString, DisplayDimensions, DisplayRotation

import pytest


def test_coord_comparison():
    c1 = Coord(0, 0)
    c2 = Coord(0, 1)
    c3 = Coord(1, 1)
    c3_other = Coord(1, 1)

    assert c1 < c3
    assert not c1 < c2, "both x,y must be greater/lt/eq"
    assert c2 <= c3

    assert c3 == c3_other, "Coords with same numbers should equal each other"
    assert c3 != c2


def test_coord_construction():
    with pytest.raises(RuntimeError):
        Coord(0, -1)


def test_bbox():
    b = BBox(Coord(1, 1), Coord(3, 2))

    assert b.width == 2
    assert b.height == 1

    assert b.contains(Coord(1, 2))
    assert not b.contains(Coord(0, 0))

    # TODO: test .intersect(other)

    with pytest.raises(RuntimeError):
        BBox(Coord(0, 0), Coord(1, 0))
    with pytest.raises(RuntimeError):
        BBox(Coord(1, 1), Coord(0, 0))


ds_testdata = [
    (DisplayRotation.R0, (0, 0, 0), {"x": 3, "y": 0}),
    (DisplayRotation.R0, (40, 2, 0), {"x": 43, "y": 2}),
    (DisplayRotation.R0, (40, 2, 1), {"x": 43, "y": 34}),
    (DisplayRotation.R90, (40, 0, 0), {"x": 66, "y": 40}),
    (DisplayRotation.R90, (120, 2, 0), {"x": 64, "y": 120}),
]


@pytest.mark.parametrize("rot, inp, expected", ds_testdata)
def test_displaystring(rot, inp, expected):
    ds = DisplayString(Coord(3, 0), DisplayDimensions(128, 64), rot)

    res = ds.translate_coord(*inp)

    assert res == expected
